@@ -1,4 +1,5 @@
 import scipy.io
+import numpy as np
 
 def loadmat(filename):
     '''
@@ -18,6 +19,8 @@ def _check_keys(dict):
     for key in dict:
         if isinstance(dict[key], scipy.io.matlab.mio5_params.mat_struct):
             dict[key] = _todict(dict[key])
+        elif isinstance(dict[key], np.ndarray) and len(dict[key]) > 0 and isinstance(dict[key][0], scipy.io.matlab.mio5_params.mat_struct):
+            dict[key] = [_todict(subelem) for subelem in elem]
     return dict
 
 def _todict(matobj):
@@ -29,6 +32,8 @@ def _todict(matobj):
         elem = matobj.__dict__[strg]
         if isinstance(elem, scipy.io.matlab.mio5_params.mat_struct):
             dict[strg] = _todict(elem)
+        elif isinstance(elem, np.ndarray) and len(elem) > 0 and isinstance(elem[0], scipy.io.matlab.mio5_params.mat_struct):
+            dict[strg] = [_todict(subelem) for subelem in elem]
         else:
             dict[strg] = elem
     return dict
